import { Database } from "@sqlite.org/sqlite-wasm";
import { Property, Model, ModelValue, QueryParams, WhereCondition, PrimitiveProperty, Config, PrimaryKeyValue, PropertyAPI, PropertyValue } from "@canvas-js/modeldb";
import { RelationAPI } from "./RelationAPI.js";
import { SqlitePrimitiveValue } from "./encoding.js";
export declare class ModelAPI {
    #private;
    readonly db: Database;
    readonly config: Config;
    readonly model: Model;
    readonly table: string;
    readonly properties: Record<string, Property>;
    readonly relations: Record<string, RelationAPI>;
    readonly relationNames: string[];
    readonly primaryProperties: PrimitiveProperty[];
    readonly mutableProperties: Property[];
    readonly codecs: Record<string, PropertyAPI<SqlitePrimitiveValue>>;
    readonly codecNames: string[];
    constructor(db: Database, config: Config, model: Model, clear?: boolean);
    private prepareStatements;
    private prepareProperty;
    addProperty(property: Property, defaultPropertyValue: PropertyValue): Promise<void>;
    removeProperty(propertyName: string): void;
    addIndex(propertyNames: string[]): void;
    removeIndex(propertyNames: string[]): void;
    private addCodec;
    private removeCodec;
    private addRelation;
    private removeRelation;
    drop(): void;
    get(key: PrimaryKeyValue | PrimaryKeyValue[]): ModelValue | null;
    getAll(): ModelValue[];
    getMany(keys: PrimaryKeyValue[] | PrimaryKeyValue[][]): (ModelValue | null)[];
    set(value: ModelValue): void;
    private encodeProperties;
    delete(key: PrimaryKeyValue | PrimaryKeyValue[]): void;
    clear(): void;
    count(where?: WhereCondition): number;
    query(query: QueryParams): ModelValue[];
    iterate(query: QueryParams): IterableIterator<ModelValue>;
    private parseRecord;
    private parseQuery;
    private getSelectExpression;
    private getWhereExpression;
}
