import { Database, Sqlite3Static } from "@sqlite.org/sqlite-wasm";
import { AbstractModelDB, ModelDBBackend, Effect, ModelValue, QueryParams, WhereCondition, Model, ModelDBInit } from "@canvas-js/modeldb";
export interface ModelDBOptions {
    sqlite3?: Sqlite3Static;
    db?: Database;
}
export declare class ModelDB extends AbstractModelDB {
    #private;
    readonly sqlite3: Sqlite3Static;
    readonly db: Database;
    static open(path: string | null, init: ModelDBInit, { db, sqlite3 }?: ModelDBOptions): Promise<ModelDB>;
    private constructor();
    protected hasModel(model: Model): boolean;
    getType(): ModelDBBackend;
    close(): Promise<void>;
    apply(effects: Effect[]): Promise<void>;
    get<T extends ModelValue>(modelName: string, key: string): Promise<T | null>;
    getAll<T extends ModelValue>(modelName: string): Promise<T[]>;
    getMany<T extends ModelValue>(modelName: string, keys: string[]): Promise<(T | null)[]>;
    count(modelName: string, where?: WhereCondition): Promise<number>;
    clear(modelName: string): Promise<void>;
    query<T extends ModelValue = ModelValue>(modelName: string, query?: QueryParams): Promise<T[]>;
    iterate<T extends ModelValue = ModelValue>(modelName: string, query?: QueryParams): AsyncIterable<T>;
    private createModel;
    private deleteModel;
    private addProperty;
    private removeProperty;
    private addIndex;
    private removeIndex;
    private getUpgradeAPI;
}
