export const quote = (name) => `"${name}"`;
export class Query {
    sql;
    statement;
    constructor(db, sql) {
        this.sql = sql;
        this.statement = db.prepare(sql);
    }
    finalize() {
        this.statement.finalize();
    }
    get(params) {
        const stmt = this.statement;
        try {
            if (params.length > 0) {
                stmt.bind(params);
            }
            if (!stmt.step()) {
                return null;
            }
            return stmt.get({});
        }
        finally {
            stmt.reset(true);
        }
    }
    all(params) {
        const stmt = this.statement;
        try {
            if (params.length > 0) {
                stmt.bind(params);
            }
            const rows = [];
            while (stmt.step()) {
                rows.push(stmt.get({}));
            }
            return rows;
        }
        finally {
            stmt.reset(true);
        }
    }
    iterate(params) {
        const stmt = this.statement;
        if (params.length > 0) {
            stmt.bind(params);
        }
        let finished = false;
        return {
            [Symbol.iterator]() {
                return this;
            },
            next() {
                if (finished) {
                    return { done: true, value: undefined };
                }
                if (stmt.step()) {
                    const value = stmt.get({});
                    return { done: false, value };
                }
                else {
                    finished = true;
                    stmt.reset(true);
                    return { done: true, value: undefined };
                }
            },
            return() {
                finished = true;
                stmt.reset(true);
                return { done: true, value: undefined };
            },
            throw(err) {
                finished = true;
                stmt.reset(true);
                throw err;
            },
        };
    }
}
export class Method {
    sql;
    statement;
    constructor(db, sql) {
        this.sql = sql;
        this.statement = db.prepare(sql);
    }
    finalize() {
        this.statement.finalize();
    }
    run(params) {
        const stmt = this.statement;
        if (params.length > 0) {
            stmt.bind(params);
        }
        try {
            stmt.step();
        }
        finally {
            stmt.reset(true);
        }
    }
}
